<?php

namespace Drupal\admin_status\Plugin\AdminStatus;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a default message.
 *
 * Because the plugin manager class for our plugins uses annotated class
 * discovery, our default message only needs to exist within the
 * Plugin\AdminStatus namespace to be declared as a plugin. This is defined in
 * \Drupal\admin_status\AdminStatusPluginManager::__construct().
 *
 * The following is the plugin annotation. This is parsed by Doctrine to make
 * the plugin definition. Any values defined here will be available in the
 * plugin definition.
 *
 * This should be used for metadata that is specifically required to instantiate
 * the plugin, or for example data that might be needed to display a list of all
 * available plugins where the user selects one. This means many plugin
 * annotations can be reduced to a plugin ID, a label and perhaps a description.
 *
 * @Plugin(
 *   id = "default_message",
 *   name = "Default Message",
 *   admin_permission = "administer admin status",
 * )
 */
class DefaultMsg extends AdminStatusPluginBase {

  /**
   * Get a description/config fields of the admin status.
   *
   * This is just an example method on our plugin that we can call to get
   * something back.
   */
  public function description() {
    return (string)$this->t('This is the default message admin status.');
  }

  /**
   * Builds a sub-form if needed to configure this plugin.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param array $configValues
   *   An array of saved configuration values for this plugin.
   * @return array
   *   A form array with any configuration form elements needed to configure
   *   this plugin.
   */
  public function configForm(array $form,
                             FormStateInterface $form_state,
                             array $configValues) {
    $form['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Sample text'),
      '#default_value' => empty($configValues['sample']) ? '' : $configValues['sample'],
    );

    return $form;
  }

  /**
   * Validates the plugin's configuration form values.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param array $configValues
   *   An array of saved configuration values for this plugin.
   */
  public function configValidateForm(array $form,
                                     FormStateInterface $form_state,
                                     array $configValues) {
    // Nothing to validate.
    return;
  }

  /**
   * Process submitted data and return configuration values to be saved.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param array $configValues
   *   An array of saved configuration values for this plugin.
   * @return array
   *   An array of configuration values to be saved for this plugin.
   */
  public function configSubmitForm(array $form,
                                   FormStateInterface $form_state,
                                   array $configValues) {
    $my_config = $form_state->getValue(
      array('plugins', 'default_message', 'config'));
    return $my_config;
  }

  /**
   * Return a status message to display.
   *
   * @return string
   */
  public function message(array $configValues) {
    return [
      [
        'status' => 'status',
        'message' =>
          [
            '#markup' => '<h3>' . $this->t('Marked Up') . '</h3><p>' . $this->t('This is a preamble message.') . '</p>'
          ],
      ],
      [
        'status' => 'warning',
        'message' => (string)$this->t('This is a default status message to display with sample text @sample', array('@sample' => $configValues['sample']))
      ],
    ];
  }

}
